@@ -2,13 +2,17 @@
 # -*- coding:utf-8 _*-
 import os
 from pprint import pprint
+import shutil
 from urllib import request
+import requests
 from urllib.request import urlopen,urlretrieve
 from bs4 import BeautifulSoup
 import threading
 from urllib.parse import quote 
 from fuzzywuzzy import fuzz
 import fire
+import configparser
+from tqdm import tqdm
 
 def web_qq_info(qq_id):
     headers = {'User-Agent':' Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3282.140 Safari/537.36 Edge/18.17763'}
@@ -96,7 +100,8 @@ def web_install_normal(web_download_url):
     print("Downloading to",web_download_name)
     urlretrieve(web_download_url,web_download_name)
     os.system(web_download_name)
-    pprint("下载完成")
+    print("下载完成")
+    os.remove(web_download_name)
 
 def web_install_hippo(web_download_url):
     web_download_name = web_download_url[web_download_url.rfind("="):]
@@ -105,6 +110,7 @@ def web_install_hippo(web_download_url):
     urlretrieve(web_download_url,web_download_name)
     os.system(web_download_name)
     print("下载完成")
+    os.remove(web_download_name)
 
 def Lensi_install(app_name,app_source):
     if app_source == "qq" or app_source == "360":
@@ -350,7 +356,69 @@ def Lensi_search(app_name):
     search_result.sort(key=app_name_cmp,reverse=True)
     return search_result
 
+def DownloadFile(download_url,app_source,DeleteWhenInstalled):
+    save_url = "D:\Lensi\Download"
+    if app_source == "qq" or app_source == "360":
+        file_name = download_url[download_url.rfind("/"):]
+        file_name = file_name.strip("/")
+    elif app_source == "hippo":
+        file_name = download_url[download_url.rfind("="):]
+        file_name = file_name.strip("=")
+    if download_url is None or save_url is None or file_name is None:
+        print('参数错误')
+        return None
+    res = requests.get(download_url,stream=True) 
+    total_size = int(int(res.headers["Content-Length"])/1024+0.5)
+    # 获取文件地址
+    file_path = os.path.join(save_url, file_name)
+    # 打开本地文件夹路径file_path，以二进制流方式写入，保存到本地
+    with open(file_path, 'wb') as fd:
+        print('开始下载文件：{},当前文件大小：{}KB'.format(file_name,total_size))
+        for chunk in tqdm(iterable=res.iter_content(1024),total=total_size,unit='k',desc=None):
+            fd.write(chunk)
+        print(file_name+' 下载完成！')
+    os.chdir("D:\Lensi\Download")
+    os.system(file_name)
+    if DeleteWhenInstalled == "True":
+        os.remove(file_name)
+
 class Lensi(object):
+    def __init__(self) -> None:
+        try:
+            if os.path.exists("D:\Lensi") == False:
+                os.mkdir("D:\Lensi")
+            if os.path.exists("D:\Lensi\Download") == False:
+                os.mkdir("D:\Lensi\Download")
+            os.chdir("D:\Lensi")
+            Lensi_config = configparser.ConfigParser()
+            Lensi_config.read("config.ini", encoding="utf-8")
+            global qq_num 
+            qq_num = Lensi_config.getint("Lensi","qq_num")
+            # print(qq_num)
+            global baoku_num 
+            baoku_num = Lensi_config.getint("Lensi","360_num")
+            global DeleteWhenInstalled
+            DeleteWhenInstalled = Lensi_config.get("Lensi","DeleteWhenInstalled")
+        except:
+            print("Initing the config.ini")
+            try:
+                os.mkdir("D:\Lensi")
+            except:
+                pass
+            try:
+                os.mkdir("D:\Lensi\Download")
+            except:
+                pass
+            os.chdir("D:\Lensi")
+            f = open("config.ini","w",encoding="utf-8")
+            init_text = "[Lensi]\nqq_num = 1\n360_num = 1\nDeleteWhenInstalled = True"
+            f.write(init_text)
+            Lensi_config = configparser.ConfigParser()
+            os.chdir("D:\Lensi")
+            Lensi_config.read("config.ini", encoding="utf-8")
+            qq_num = Lensi_config.getint("Lensi", "qq_num")
+            baoku_num = Lensi_config.getint("Lensi", "360_num")
+            DeleteWhenInstalled = Lensi_config.getboolean("Lensi","DeleteWhenInstalled") 
     def info_s(self,app_name,app_source):
         if app_source == "qq":
             pprint(web_qq_info(lensi_search_all("qq",app_name,1)[0][4]))
@@ -358,6 +426,7 @@ class Lensi(object):
             pprint(web_baoku_info(lensi_search_all("360",app_name,1)[0][4]))
         elif app_source == "Hippo":
             pprint(web_hippo_info(app_name))
+
     def info(self,app_name):
         print("QQ")
         try:
@@ -378,31 +447,43 @@ class Lensi(object):
             print(web_hippo_info(app_name))
         except:
             print("None")
+
     def install_s(self,app_name,app_source):
         if app_source == "qq" or app_source == "360":
             web_install_normal(app_name)
         elif app_source == "hippo":
             web_install_hippo(app_name)
+
     def install(self,app_name):
         try:
             print("Downloading from Hippo")
             download_url = hippo_search_easy(app_name)[0][5]
             # print(download_url)
-            web_install_hippo(download_url)
+            DownloadFile(download_url,"hippo")
         except:
             print("Hippo failed")
             print("Downloading from QQ")
-            web_install_normal(web_qq_search(app_name,1)[0][5])
-    def search(self,source,app_name,limmit_num):#搜索大函数
+            download_url = web_qq_search(app_name,1)[0][5]
+            DownloadFile(download_url,"qq",DeleteWhenInstalled)
+    
+    def search_s(self,source,app_name,limmit_num):#搜索大函数
+        source = str(source)
         if source == "-360" or source == "360":
             pprint(web_360_search(app_name,limmit_num))
         elif source == "-Q" or source == "qq":
             pprint(web_qq_search(app_name,limmit_num))
         elif source == "-H" or source == "Hippo":
             pprint(hippo_search_easy(app_name))
+
     def search(self,app_name):
-        thread_360 = myThread("360", app_name,1)
-        thread_qq = myThread("qq", app_name,1)
+        if app_name == "Lensi":
+            print("? You have installed it ,haven't you ?")
+            return 
+        if app_name == "Lensit":
+            print("QEIE1284213AAUEUUQQ")
+            print("I don't know what it means.")
+        thread_360 = myThread("360", app_name,baoku_num)
+        thread_qq = myThread("qq", app_name,qq_num)
         thread_H = myThread("Hippo", app_name,1)
         #多线程
         search_result = []
@@ -425,6 +506,7 @@ class Lensi(object):
         # pprint(search_result)
         search_result.sort(key=app_name_cmp,reverse=True)
         pprint(search_result)
+    
     def yiju(self):
         headers = {'User-Agent':' Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/64.0.3282.140 Safari/537.36 Edge/18.17763'}
         url = 'https://yijuzhan.com/api/word.php'
@@ -432,9 +514,39 @@ class Lensi(object):
         html = urlopen(req)
         html_text = bytes.decode(html.read())
         print(html_text)
-        print("古诗API来自一句")
-    def mt(self):
-        print("97HE783GE")
+        print("(古诗API来自一句)")
+
+    def set_init(self):
+        try:
+            os.mkdir("D:\Lensi")
+        except:
+            pass
+        try:
+            os.mkdir("D:\Lensi\Download")
+        except:
+                pass
+        os.chdir("D:\Lensi")
+        f = open("config.ini","w",encoding="utf-8")
+        init_text = "[Lensi]\nqq_num = 1\n360_num = 1\nDeleteWhenInstalled = True"
+        f.write(init_text)
+
+    def clean(self):
+        shutil.rmtree("D:\Lensi\Download")
+        os.mkdir("D:\Lensi\Download")
+        print("Has cleaned D:\Lensi\Download")
+    
+    def set(self,options,le_set):
+        le_set =str(le_set)
+        Lensi_config = configparser.ConfigParser()
+        os.chdir("D:\Lensi")
+        Lensi_config.read("config.ini", encoding="utf-8")
+        if options == "qq_num":
+            Lensi_config.set("Lensi","qq_num",le_set)
+        elif options == "baoku_num":
+            Lensi_config.set("Lensi","360_num",le_set)
+        elif options == "DeleteWhenInstalled":
+            Lensi_config.set("Lensi", "DeleteWhenInstalled",le_set)
+        Lensi_config.write(open("config.ini", "w"))
 
 def main():
-    fire.Fire(Lensi)
+    fire.Fire(Lensi)
\ No newline at end of file
